ORIGINAL_ID = "Original Id"
NEW_ID = "New Id"
ERROR = "Error"
OPTION_DEFAULTS = {
    "bulk-api-poll-interval": 5,
    "bulk-api-timeout": 1200,
    "bulk-api-batch-size": 10000,
    "bulk-api-mode": "Parallel",
    "api-version": "52.0",
}
